### 0.9.0

```{rubric} Features
```
* added support for GPU enabled {class}`~anndata.AnnData` {pr}`60` {smaller}`S Dicks`
* added support for dense `cupy.ndarray` {pr}`60` {smaller}`S Dicks`
* added support for 64 bit floats {pr}`60` {smaller}`S Dicks`
* added `rapids_singlecell.utils` to help with {class}`~anndata.AnnData` GPU conversion  {pr}`60` {smaller}`S Dicks`
* renamed `cunndata_funcs` to {mod}`~rapids_singlecell.pp` {pr}`60` {smaller}`S Dicks`
* renamed `scanpy_gpu` to {mod}`~rapids_singlecell.tl` {pr}`60` {smaller}`S Dicks`
* switched {func}`~rapids_singlecell.pp.neighbors` to {mod}`~rapids_singlecell.pp` {pr}`60` {smaller}`S Dicks`
* switched {func}`~rapids_singlecell.pp.harmony_integrate` to {mod}`~rapids_singlecell.pp` {pr}`60` {smaller}`S Dicks`
* deprecated `rapids_singlecell.cunnData.cunnData` {pr}`60` {smaller}`S Dicks`

```{rubric} Docs
```
* updated Usage_Principles {pr}`60` {smaller}`L Heumos & S Dicks`
* added a release-notes {pr}`60` {smaller}`P Angerer & S Dicks`
* changed notebooks to work with anndata {pr}`60` {smaller}`S Dicks`

```{rubric} Bug fixes
```

* Fix `rapids_singlecell.preprocessing._utils._get_mean_var` {pr}`60` {smaller}`S Dicks`
* Fix {func}`~rapids_singlecell.pp.harmony_integrate` reproducibility {pr}`60` {smaller}`S Dicks`
* Fix {mod}`~rapids_singlecell.dcg` to work with `decoupler` version 1.5.0 {pr}`60` {smaller}`S Dicks`


```{rubric} Misc
```

* tests now work with anndata
